Spyder plugin for **modelx**
============================

Spyder plugin to add custom consoles and widgets for
`modelx <https://github.com/fumitoh/spyder-modelx>`_ .

See `modelx site <https://docs.modelx.io>`_ .

Build status
------------
|travis status| |appveyor status| |circleci status| |coverage| |scrutinizer|

Project information
-------------------
|license| |pypi version| |gitter|

.. |travis status| image:: https://img.shields.io/travis/fumitoh/spyder-modelx/master.svg
  :target: https://travis-ci.org/fumitoh/spyder-modelx
  :alt: Travis-CI build status
.. |appveyor status| image:: https://img.shields.io/appveyor/ci/fumitoh/spyder-modelx/master.svg
  :target: https://ci.appveyor.com/project/fumitoh/spyder-modelx
  :alt: Appveyor build status
.. |circleci status| image:: https://img.shields.io/circleci/project/github/fumitoh/spyder-modelx/master.svg
  :target: https://circleci.com/gh/fumitoh/spyder-modelx/tree/master
  :alt: Circle-CI build status
.. |scrutinizer| image:: https://img.shields.io/scrutinizer/g/fumitoh/spyder-modelx.svg
  :target: https://scrutinizer-ci.com/g/fumitoh/spyder-modelx/?branch=master
  :alt: Scrutinizer Code Quality
.. |license| image:: https://img.shields.io/pypi/l/spyder-modelx.svg
  :target: LICENSE.txt
  :alt: License
.. |pypi version| image:: https://img.shields.io/pypi/v/spyder-modelx.svg
  :target: https://pypi.python.org/pypi/spyder-modelx
  :alt: Latest PyPI version
.. |gitter| image:: https://badges.gitter.im/fumitoh/spyder-modelx.svg
  :target: https://gitter.im/fumitoh/spyder-modelx
  :alt: Join the chat at https://gitter.im/fumitoh/spyder-modelx
.. |coverage| image:: https://coveralls.io/repos/github/fumitoh/spyder-modelx/badge.svg
  :target: https://coveralls.io/github/fumitoh/spyder-modelx?branch=master
  :alt: Code Coverage


Description
-----------
Spyder plugin for modelx.

Installation
------------

Using pip

``pip install spyder_modelx``

Usage
-----
See https://docs.modelx.io
